verticalDragThreshold property
Fraction of screen height that must be dragged to trigger expand/collapse when velocity is below threshold.
Implementation
final double verticalDragThreshold;
Fraction of screen height that must be dragged to trigger expand/collapse when velocity is below threshold.
final double verticalDragThreshold;