CardPhase enum

Discrete state machine phases for the morphing card carousel.

Transitions:

CollapsedCard
  ↓ vertical drag up
TransitioningToFull
  ↓ complete
Fullscreen
  ↓ vertical drag down
TransitioningToCard
  ↓ complete
CollapsedCard
Inheritance
Available extensions

Values

collapsedCard → const CardPhase
transitioningToFull → const CardPhase
fullscreen → const CardPhase
transitioningToCard → const CardPhase

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CardPhase>
A constant List of the values in this enum, in order of their declaration.