snapDistanceThreshold property
Fraction of card width that must be dragged to trigger snap when velocity is below snapVelocityThreshold.
Implementation
final double snapDistanceThreshold;
Fraction of card width that must be dragged to trigger snap when velocity is below snapVelocityThreshold.
final double snapDistanceThreshold;