grid property
Whether to render the items in a responsive grid layout. If false, uses a standard list view.
Implementation
final bool grid;
Whether to render the items in a responsive grid layout. If false, uses a standard list view.
final bool grid;