MorphPhase enum

Unified discrete phases for any morph transition.

Used by MorphController to represent the current animation state.

collapsed
  ↓ expand() / tap
expanding
  ↓ animation completes
expanded
  ↓ collapse() / drag down
collapsing
  ↓ animation completes
collapsed

dragging can be entered from expanded or collapsed and resolves to either expanding or collapsing on gesture end.

Inheritance
Available extensions

Values

collapsed → const MorphPhase

Source state — card / sheet / custom rect visible.

expanding → const MorphPhase

Animating from source → target (card → fullscreen).

expanded → const MorphPhase

Target state — fullscreen / expanded view visible.

collapsing → const MorphPhase

Animating from target → source (fullscreen → card).

dragging → const MorphPhase

User is actively dragging — animation is paused.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MorphPhase>
A constant List of the values in this enum, in order of their declaration.