enabled property

bool enabled
final

Whether shared element animation is enabled for this element.

Setting to false suppresses per-element animation while keeping the tag for identification purposes.

Implementation

final bool enabled;