ThumbnailSelectorBar<T> class
Horizontal strip of circular thumbnail selectors at the bottom of the screen.
Each circle shows a product thumbnail. Active item has a highlight border. Strip is horizontally scrollable. Fades out as vertical progress increases.
Uses raw Opacity and Transform — no implicit animation widgets. Wrapped in RepaintBoundary for isolation.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ThumbnailSelectorBar
Constructors
-
ThumbnailSelectorBar({Key? key, required CardCarouselController controller, required List<
T> items, required Widget thumbnailBuilder(BuildContext context, T item, bool isActive), double thumbnailSize = 56.0, double spacing = 12.0, Color? activeBorderColor, double activeBorderWidth = 2.5, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16.0, vertical: 12.0)}) -
const
Properties
- activeBorderColor → Color?
-
final
- activeBorderWidth → double
-
final
- controller → CardCarouselController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
final
- thumbnailBuilder → Widget Function(BuildContext context, T item, bool isActive)
-
Builds each circular thumbnail. Receives item and whether it's active.
final
- thumbnailSize → double
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ThumbnailSelectorBar< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited