OverlayPhase enum
State machine phases for the overlay carousel morph transition.
Idle
↓ selectItem(item, originRect)
Appearing (originRect → centered card)
↓ animation completes
CardMode (carousel active, horizontal swipe)
↓ drag up
Expanding (card → fullscreen)
↓ animation completes
Fullscreen
↓ drag down
Collapsing (fullscreen → card)
↓ animation completes
CardMode
↓ drag down / tap scrim
Disappearing (card → originRect)
↓ animation completes
Idle
Values
- idle → const OverlayPhase
- appearing → const OverlayPhase
- cardMode → const OverlayPhase
- expanding → const OverlayPhase
- fullscreen → const OverlayPhase
- collapsing → const OverlayPhase
- disappearing → const OverlayPhase
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OverlayPhase> - A constant List of the values in this enum, in order of their declaration.